Terms of Service • Zeitgitter Server at ZEITGITTER_DOMAIN

- Home
- Terms of Service
- Privacy Policy
- Contact Information

# Terms and Conditions

The Zeitgitter service at ZEITGITTER_DOMAIN is provided free of charge to Internet users ("You") by ZEITGITTER_OWNER ("Operator"), on the following terms; by using this Zeitgitter service you (for yourselves and anybody claiming under you) accept these terms in their entirety and agree to be bound by them.

In these terms:

- use includes both actual and attempted use
- you includes both you and any other person or body who seeks to claim through you or on your behalf any term purporting to provide protection for or release of or indemnity to Operator shall also extend for the benefit of its servants and agents.

- You may only use this Zeitgitter service if you accept these terms in their entirety and unmodified in any way, and you agree use of Stamper outside these terms would be wholly unlawful and unauthorised.
- You will not use this Zeitgitter service in furtherance of or in connection with any unlawful purpose, or in any way which is or may be unlawful under the laws of any relevant jurisdiction.
- You will not attempt to overload this Zeitgitter service or try to obtain unauthorized access to services and data maintained on this server.
- Operator reserves the right to specifically withdraw the use of this Zeitgitter service from any person or body without notice.
- You agree that no liability shall attach to Operator under any circumstances in relation to any use of stamper by you, and by using stamper you wholly release Operator from any such liability to the fullest extent permitted by law.
- You agree to fully indemnify Operator against any liability it may incur (including the legal costs of a successful defence or of a compromise) on the indemnity basis as a result of any claim being made against us in relation to your use of this Zeitgitter service.
- This Zeitgitter service is provided on an as is basis, and you agree that, in view of the fact that this Zeitgitter service is provided free of charge, these terms are reasonable in every way.
- You agree that the laws of ZEITGITTER_COUNTRY shall be the applicable law in relation to these terms and to the use of this Zeitgitter service, and that the courts of that country shall have exclusive jurisdiction in all such matters.

These terms of service are based on the terms the PGP Digital Timestamper.